"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.P1MeterApi = void 0;
const base_api_1 = require("./base-api");
const telegram_1 = require("./utils/telegram");
class P1MeterApi extends base_api_1.BaseApi {
    getBasicInformation() {
        return super.getBasicInformation();
    }
    getData() {
        return super.getData();
    }
    startPolling(method, apiMethod) {
        return super.startPolling(method, apiMethod);
    }
    constructor(baseUrl, options) {
        super(baseUrl, options);
    }
    get endpoints() {
        const { baseUrl } = this;
        return {
            ...super.endpoints,
            telegram: `${baseUrl}/api/${this.apiVersion}/telegram`,
        };
    }
    /**
     * Start polling your P1 Meter using a specific method.
     *
     * To start polling, call the `start()` method on the returned object.
     * The polling can be stopped by calling the `stop()` method.
     *
     * Supported methods: `getData`, `getTelegram`
     */
    get polling() {
        const getTelegram = 'getTelegram';
        return {
            ...super.polling,
            [getTelegram]: {
                start: () => super.startPolling(getTelegram, this.getTelegram.bind(this)),
                stop: () => super.stopPolling(getTelegram),
                on: super.on.bind(this),
            },
        };
    }
    /**
     * The /api/v1/telegram endpoint returns the most recent, valid telegram that was given by the P1 meter,
     * therefore this endpoint is only available for the HWE-P1.
     *
     * The telegram validated with its CRC, but not parsed in any form.
     *
     * Note that this endpoint returns plain text instead of formatted JSON, even when an error occours (see Error handling)
     *
     * @link: https://homewizard-energy-api.readthedocs.io/endpoints.html#p1-telegram-api-v1-telegram
     */
    async getTelegram() {
        const url = this.endpoints.telegram;
        this.log(`Fetching telegram at ${url}`);
        const method = 'GET';
        const response = await this.request(url, {
            method,
        });
        if (!this.isResponseOk(response)) {
            return this.throwResponseError(url, method, response);
        }
        // Telegram endpoint returns plain text
        const data = (await response.body.text());
        this.log(`Received telegram ${JSON.stringify(data)} from ${this.endpoints.telegram}`);
        return data;
    }
    /**
     * The /api/v1/telegram endpoint returns the most recent, valid telegram that was given by the P1 meter in a text format.
     *
     * This method fetches the telegram and parses it and returns it as a JSON object.
     */
    async getParsedTelegram() {
        const telegram = await this.getTelegram();
        const parsedTelegram = (0, telegram_1.parseTelegram)(telegram);
        this.log(`Parsed telegram ${JSON.stringify(parsedTelegram)} from ${this.endpoints.telegram}`);
        return parsedTelegram;
    }
}
exports.P1MeterApi = P1MeterApi;
//# sourceMappingURL=p1-meter-api.js.map